use eframe::egui;
use model_response::ModelResponse;
use state::AppState;

pub mod model_response;
pub mod state;

pub fn main() -> eframe::Result {
    let options = eframe::NativeOptions {
        viewport: eframe::egui::ViewportBuilder::default().with_inner_size([900.0, 600.0]),
        ..Default::default()
    };

    eframe::run_native(
        "Groq Model Comparison",
        options,
        Box::new(|cc| Ok(Box::new(AppState::new(cc)))),
    )
}

impl eframe::App for AppState {
    fn update(&mut self, ctx: &egui::Context, _frame: &mut eframe::Frame) {
        egui::CentralPanel::default().show(ctx, |ui| {
            ui.heading("Groq Model Comparison");
            ui.label("Compare Groq models with ease!");

            ui.horizontal(|ui| {
                let counter_color = match self.counter {
                    0 => egui::Color32::WHITE,
                    _ if self.counter > 0 => egui::Color32::GREEN,
                    _ => egui::Color32::RED,
                };

                ui.label("Counter:");
                ui.label(egui::RichText::new(format!("{}", self.counter)).color(counter_color));
            });

            ui.horizontal(|ui| {
                if ui.button("Increment").clicked() {
                    self.counter += 1;
                }

                if ui.button("Decrement").clicked() {
                    self.counter -= 1;
                }
            });

            ui.add(ModelResponse::new(
                "This is a test message".to_string(),
                200,
                100,
            ));
        });
    }
}
